// $Id: DummyMidiOutDevice.cc 8352 2008-11-12 18:39:08Z m9710797 $

#include "DummyMidiOutDevice.hh"

namespace openmsx {

void DummyMidiOutDevice::recvByte(byte /*value*/, EmuTime::param /*time*/)
{
	// ignore
}

const std::string& DummyMidiOutDevice::getDescription() const
{
	static const std::string EMPTY;
	return EMPTY;
}

void DummyMidiOutDevice::plugHelper(
		Connector& /*connector*/, EmuTime::param /*time*/)
{
}

void DummyMidiOutDevice::unplugHelper(EmuTime::param /*time*/)
{
}

} // namespace openmsx
